# TextFlow

#### Annotation Simplified

---

[![Build](https://github.com/ysenarath/textflow/workflows/Python%20package/badge.svg)](https://github.com/ysenarath/textflow)
[![Docs](https://readthedocs.org/projects/pip/badge?version=latest&style=flat)](https://docs.textflow.app/)
[![Version](https://img.shields.io/pypi/v/textflow)](https://pypi.org/project/textflow/)

---

### Quick Documentation

TextFlow is a minimalist interface for full text processing with natural language tools. As of now, the app is capable of running projects from end to end.
i.e. it is capable of getting annotations, processing them and creating models on the fly. There are two (2) main components of this system:

1. Annotator
    1. Interface for Annotation
    2. Annotation Agreement
2. Modeling
    1. Automatic Model Training
    2. Automated Model Evaluation
    
The platform is highly extensible for running a specific NLP project and very much beneficial for researchers. 
    
To read the full documentation please visit [here](https://docs.textflow.app/) (not complete).

---

### Contributions

We highly value your feedback on this project, 
so let us know. Kindly place an issue for any bugs or feature recommendations.

---

### About

You can contact the author via his e-mail:`ysenarath.93@gmail.com`.
